# Generated by Django 2.1.4 on 2019-03-28 13:59

from django.db import migrations, models
import wagtail.core.blocks
import wagtail.core.fields
import wagtail.images.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_events', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='event',
            name='body',
            field=wagtail.core.fields.StreamField([('heading', wagtail.core.blocks.CharBlock(help_text="Add optional subheadings between paragraphs, if you're describing the event series in more detail", label='Subheading', max_length=120, required=False)), ('paragraph', wagtail.core.blocks.TextBlock(help_text='Tell people about the event series', label='Text', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(help_text='Add images to describe the event series.', label='Image', required=False)), ('quote', wagtail.core.blocks.BlockQuoteBlock(help_text='Add an inspirational quote!', label='Quote', required=False))], blank=True, help_text='Optional: Add further description of this event.'),
        ),
        migrations.AlterField(
            model_name='event',
            name='description',
            field=models.TextField(blank=True, help_text='Briefly describe your event', max_length=400),
        ),
    ]
